# Secoda Common

Secoda Common library holds common codes among micro services in Secoda.
For information about Secoda and our other services, visit the [main repository](https://github.com/secoda/secoda).

## Requirements
- Python = 3.7.9
